@@ -570,9 +570,9 @@ class Channel(virtual.Channel):
                     try:
                         message = loads(bytes_to_str(payload['data']))
                     except (TypeError, ValueError):
-                        message = None
                         warn('Cannot process event on channel %r: %r',
                              channel, payload, exc_info=1)
+                        raise Empty()
                     return message, self._fanout_to_queue[channel]
         raise Empty()
 
